
import mx.central.Shell;
import mx.central.controls.MIconButton;

/**
 * Hello World sample application for Macromedia Central 1.5.
 * Handles clicks on the main MovieClip, shows Status and Progress info,
 * opens a Pod, and handles resizing.
 *
 * @author Macromedia
 * @version 1.5
 */
class HelloWorld implements mx.central.Application {

    var oShell:Shell;
    var bOnline:Boolean;
	var oRoot:MovieClip;
    var oMessageBox:MovieClip;
	var bStatusIsShowing = false;

	/**
     * Constructor saves a local reference to the root timeline and the MessageBox movie clip
	 */
    function HelloWorld(root:MovieClip) {
        oRoot = root;
		oMessageBox = oRoot.fHelloWorld;
    }
	
    /**
     * Called by the Shell when our application is loaded.
	 */
	function onActivate (shell:Shell, appID:Number, shellID:Number, baseTabindex:Number, initiaData:Object):Void {
		// keep a reference to the Shell so we can call functions on it
		oShell = shell;
	
		// update network connection
		onNetworkChange(oShell.isConnected());
		
		// define a local var to help the oMessageBox.onRelease function
		// figure out the correct scoping
		var hw:HelloWorld = this;
		
		// Handle clicks anywhere on the oMessageBox MovieClip
		// (well, on any non-blank pixel anyway)
		oMessageBox.onRelease = function()
		{
			// show the pod if it's not already showing
			hw.showPod();
			
			// toggle the status message and progress bar
			if (!hw.bStatusIsShowing) {
				
				// Updates status bar with current time
				var now = new Date();
				hw.oShell.setStatus("Hello! It's now "+now.toString());
			
				// show progress bar, which can accept the following values:
				//   -1 shows indeterminate progress (barber pole)
				//   1-100% for normal progress bar
				//   0 or over 100% hides the bar
				hw.oShell.setProgress(-1);
			}
			else
			{
				hw.oShell.setStatus("");
				hw.oShell.setProgress(0);
			}
			hw.bStatusIsShowing = !hw.bStatusIsShowing;
		}
	
		// layout to initial size
		onResize();
	}
	
	/**
	 * Called by the Shell when online status changes
	 */
	function onNetworkChange (connected:Boolean):Void
	{
		bOnline = connected;
	
		// update hello world message to show current connectedness
		oMessageBox.message.text = "Hello " + (bOnline ? "Online" : "Offline") + " World!";
	}
	
	/**
	 * Called by the Shell when the window is resized
	 */
	function onResize (Void):Void {
		// get new size
		var bounds = oShell.getBounds();
		
		// if the bounds weren't returned, just use the stage size
		if (oShell == null)
		{
			bounds = {width: Stage.width, height: Stage.height};
		}
		
		// layout application items
		// center on stage
		oRoot._x = Math.round( (bounds.width - oRoot._width) / 2); 
		oRoot._y = Math.round( (bounds.height - oRoot._height) / 2);
		
		// displays bounds information while resizing
		oShell.setStatus("bounds.width, bounds.height = " + bounds.width + ", " + bounds.height);
	}
	
	/**
	 * Called by the Shell when information is blasted to this application
	 */
	function onSelectedItem (data:Array):Void {
		oShell.setStatus("Got selected item.");
	}
	
	/**
	 * Opens the Pod for this App, if it's not open already.
	 */
	function showPod() {
		// Gets the id of the one pod for this app.
		var aPods:Array = oShell.getPods();
		var oPod:Object = aPods[0];
		
		// Displays the pod if it's not already being viewed.
		var aViewedPods = oShell.getViewedPods();
		if (aViewedPods.length == 0) {
			oShell.viewPod (oPod.id);
		}
	}
	
	/**
	 * Other Application methods that are not implemented in this application.
	 */
	function onDeactivate (Void):Void {}
	function onNoticeEvent (event:Object, noticeData:Object, initalData:Object):Void {}
	function onPaymentResult (result:Boolean, transactionID:Object):Void {}
	function onUninstall (Void):Void {}
	function showPreferences (Void):Void {}
	function getMinimumSize (Void):Object { 
		return null; 
	}
}
